[][src]Trait chopper_lib::util::preview::Preview

pub trait Preview {
    fn get_lines(&self) -> &Option<Vec<String>>;
fn get_buf(&self) -> &Box<[u8]>;
fn get_reader(self: Box<Self>) -> Box<dyn Read>; }

Required methods

fn get_lines(&self) -> &Option<Vec<String>>

'None' means that there was an error parsing buffer as vector of valid strings

fn get_buf(&self) -> &Box<[u8]>

buf will be trimmed down to number of bytes that was actually read, if it's less than the default buf capacity

fn get_reader(self: Box<Self>) -> Box<dyn Read>

Loading content...

Implementors

impl<R: 'static + Read> Preview for ChopperBufPreviewer<R>[src]

Loading content...