[−][src]Trait chopper_lib::util::preview::Preview
Required methods
fn get_lines(&self) -> &Option<Vec<String>>
'None' means that there was an error parsing buffer as vector of valid strings
fn get_buf(&self) -> &Box<[u8]>
buf will be trimmed down to number of bytes that was actually read, if it's less than the default buf capacity